==> haskell-network-multicast-0.2.0-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-multicast
version: 0.2.0
id: network-multicast-0.2.0-DQnwJPprlBYFPKgpuSflA9
key: network-multicast-0.2.0-DQnwJPprlBYFPKgpuSflA9
license: PublicDomain
copyright: 2008-2016 Audrey Tang
maintainer: Marco Zocca
stability: experimental
synopsis: Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.
category: Network
author: Audrey Tang <audreyt@audreyt.org>
exposed: True
indefinite: False
exposed-modules:
    Network.Multicast
abi: de1864bebbddc94f4a174882089a2e54
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/network-multicast-0.2.0
library-dirs: /usr/lib/ghc-8.2.2/site-local/network-multicast-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/network-multicast-0.2.0
hs-libraries: HSnetwork-multicast-0.2.0-DQnwJPprlBYFPKgpuSflA9
depends:
    base-4.10.1.0 network-2.6.3.4-4K065be0R6PJVLRtkEGbjz
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             network-2.6.3.4-4K065be0R6PJVLRtkEGbjz=20387964172162461d5c295001ad0241
haddock-interfaces: /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock
haddock-html: /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-network-multicast-0.2.0-15-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-network-multicast.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: network-multicast
version: 0.2.0
id: network-multicast-0.2.0-37A8uR5tl2QKm5iVWfmu0j
key: network-multicast-0.2.0-37A8uR5tl2QKm5iVWfmu0j
license: LicenseRef-PublicDomain
copyright: 2008-2016 Audrey Tang
maintainer: Marco Zocca
author: Audrey Tang <audreyt@audreyt.org>
stability: experimental
synopsis: Simple multicast library
description:
    The "Network.Multicast" module is for sending
    UDP datagrams over multicast (class D) addresses.
category: Network
abi: 64eff76ec98667430f7c08dcea024bdc
exposed: True
exposed-modules:
    Network.Multicast
import-dirs: /usr/lib/ghc-8.4.2/site-local/network-multicast-0.2.0
library-dirs: /usr/lib/ghc-8.4.2/site-local/network-multicast-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/network-multicast-0.2.0
hs-libraries: HSnetwork-multicast-0.2.0-37A8uR5tl2QKm5iVWfmu0j
depends:
    base-4.11.1.0 network-2.6.3.5-Ey5nELlCFMCCJfToLl8AVa
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             network-2.6.3.5-Ey5nELlCFMCCJfToLl8AVa=2ccacb7c7507f165c3f664c3e6d39bf6
haddock-interfaces: /usr/share/doc/haskell-network-multicast/html/network-multicast.haddock
haddock-html: /usr/share/doc/haskell-network-multicast/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
